# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import server_manager_pb2 as server__manager__pb2


class ServerManagerStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.StartNewServer = channel.unary_unary(
        '/robo_gym_server_manager.grpc_msgs.server_manager.ServerManager/StartNewServer',
        request_serializer=server__manager__pb2.RobotServer.SerializeToString,
        response_deserializer=server__manager__pb2.RobotServer.FromString,
        )
    self.KillServer = channel.unary_unary(
        '/robo_gym_server_manager.grpc_msgs.server_manager.ServerManager/KillServer',
        request_serializer=server__manager__pb2.RobotServer.SerializeToString,
        response_deserializer=server__manager__pb2.RobotServer.FromString,
        )
    self.KillAllServers = channel.unary_unary(
        '/robo_gym_server_manager.grpc_msgs.server_manager.ServerManager/KillAllServers',
        request_serializer=server__manager__pb2.RobotServer.SerializeToString,
        response_deserializer=server__manager__pb2.RobotServer.FromString,
        )
    self.VerifyConnection = channel.unary_unary(
        '/robo_gym_server_manager.grpc_msgs.server_manager.ServerManager/VerifyConnection',
        request_serializer=server__manager__pb2.Empty.SerializeToString,
        response_deserializer=server__manager__pb2.Status.FromString,
        )


class ServerManagerServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def StartNewServer(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def KillServer(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def KillAllServers(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def VerifyConnection(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ServerManagerServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'StartNewServer': grpc.unary_unary_rpc_method_handler(
          servicer.StartNewServer,
          request_deserializer=server__manager__pb2.RobotServer.FromString,
          response_serializer=server__manager__pb2.RobotServer.SerializeToString,
      ),
      'KillServer': grpc.unary_unary_rpc_method_handler(
          servicer.KillServer,
          request_deserializer=server__manager__pb2.RobotServer.FromString,
          response_serializer=server__manager__pb2.RobotServer.SerializeToString,
      ),
      'KillAllServers': grpc.unary_unary_rpc_method_handler(
          servicer.KillAllServers,
          request_deserializer=server__manager__pb2.RobotServer.FromString,
          response_serializer=server__manager__pb2.RobotServer.SerializeToString,
      ),
      'VerifyConnection': grpc.unary_unary_rpc_method_handler(
          servicer.VerifyConnection,
          request_deserializer=server__manager__pb2.Empty.FromString,
          response_serializer=server__manager__pb2.Status.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'robo_gym_server_manager.grpc_msgs.server_manager.ServerManager', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
